Add default implementation of printing interface


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@4727 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Target/TargetInstrInfo.cpp b/lib/Target/TargetInstrInfo.cpp
index 115f2c2..5dca701 100644
--- a/lib/Target/TargetInstrInfo.cpp
+++ b/lib/Target/TargetInstrInfo.cpp
@@ -1,11 +1,10 @@
 //===-- TargetMachine.cpp - General Target Information ---------------------==//
 //
-// This file describes the general parts of a Target machine.
-// This file also implements MachineInstrInfo and MachineCacheInfo.
 //
 //===----------------------------------------------------------------------===//
 
 #include "llvm/Target/MachineInstrInfo.h"
+#include "llvm/CodeGen/MachineInstr.h"
 #include "llvm/Constant.h"
 #include "llvm/DerivedTypes.h"
 
@@ -34,6 +33,9 @@
   TargetInstrDescriptors = NULL;	// reset global variable
 }
 
+void MachineInstrInfo::print(const MachineInstr *MI, std::ostream &O) const {
+  O << *MI;
+}
 
 bool MachineInstrInfo::constantFitsInImmedField(MachineOpCode opCode,
                                                 int64_t intValue) const {
@@ -1,11 +1,10 @@
-//===-- TargetMachine.cpp - General Target Information ---------------------==//
+//===-- MachineInstrInfo.cpp - Target Instruction Information -------------===//
 //